"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var Store_1 = require("../Store");
describe('Store resolve foreign method', function () {
    var store;
    var data = [{ id: 1 }];
    var instances = [{ key: function () { return data[0].id; } }];
    var options = { url: 'url' };
    beforeEach(function () {
        store = new Store_1.default(null);
        store.make = jest.fn().mockReturnValue(instances);
    });
    it('should convert single result to array', function () {
        store.resolveForeign(data[0], options);
        expect(store.make).toHaveBeenCalledWith(data);
    });
    it('should convert result to list of model instances', function () {
        store.resolveForeign(data, options);
        expect(store.make).toHaveBeenCalledWith(data);
    });
    it('should add list to cache', function () {
        store.resolveForeign(data, options);
        expect(store.cache.getList('url')).toBeTruthy();
    });
    it('should add model to cache', function () {
        store.cache.set = jest.fn();
        store.resolveForeign(data, __assign({}, options, { set: true }));
        expect(store.cache.set).toHaveBeenCalledWith(instances, false);
    });
    it('should not add model to cache', function () {
        store.cache.set = jest.fn();
        store.resolveForeign(data, options);
        expect(store.cache.set).not.toHaveBeenCalled();
    });
    it('should resolve model instances', function () {
        expect(store.resolveForeign(data, options)).toBe(instances);
    });
});
//# sourceMappingURL=ResolveForeign.spec.js.map